.. currentmodule:: sardana.pool.poolmotor

:mod:`~sardana.pool.poolmotor`
=========================================

.. automodule:: sardana.pool.poolmotor

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`PoolMotor`


PoolMotor
-------------------

.. inheritance-diagram:: PoolMotor
    :parts: 1
    
.. autoclass:: PoolMotor
    :show-inheritance:
    :members:
    :undoc-members:

